pm4py.objects.ocel.util package
===============================

Submodules
----------

pm4py.objects.ocel.util.attributes\_names module
------------------------------------------------

.. automodule:: pm4py.objects.ocel.util.attributes_names
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.objects.ocel.util.extended\_table module
----------------------------------------------

.. automodule:: pm4py.objects.ocel.util.extended_table
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.objects.ocel.util.filtering\_utils module
-----------------------------------------------

.. automodule:: pm4py.objects.ocel.util.filtering_utils
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.objects.ocel.util.flattening module
-----------------------------------------

.. automodule:: pm4py.objects.ocel.util.flattening
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.objects.ocel.util.related\_events module
----------------------------------------------

.. automodule:: pm4py.objects.ocel.util.related_events
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.objects.ocel.util.related\_objects module
-----------------------------------------------

.. automodule:: pm4py.objects.ocel.util.related_objects
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.objects.ocel.util
   :members:
   :undoc-members:
   :show-inheritance:
